@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <QMenu>
 #include <QPixmap>
@@ -27,7 +26,6 @@
 
 #include "libgui/MenuGroup.h"
 #include "libgui/MenuItem.h"
-#include "libgui/MenuNode.h"
 
 //*****************************************************************************
 Kwave::MenuItem::MenuItem(Kwave::MenuNode *parent,
@@ -36,7 +34,7 @@ Kwave::MenuItem::MenuItem(Kwave::MenuNode *parent,
                           const QKeySequence &shortcut,
                           const QString &uid)
     :Kwave::MenuNode(parent, name, command, shortcut, uid),
-     m_exclusive_group(), m_action(Q_NULLPTR)
+     m_exclusive_group(), m_action(nullptr)
 {
     Q_ASSERT(parent);
     if (!parent) return;
@@ -161,3 +159,5 @@ void Kwave::MenuItem::setIcon(const QIcon &icon)
 
 //***************************************************************************
 //*****************************************************************************
+
+#include "moc_MenuItem.cpp"
