@@ -56,12 +56,12 @@ namespace Kwave
                 const QString &uid);
 
         /** Destructor */
-        virtual ~MenuSub() Q_DECL_OVERRIDE;
+        ~MenuSub() override;
 
         /**
          * Always returns true, as the nodes of this type are branches.
          */
-        virtual bool isBranch() const Q_DECL_OVERRIDE { return true; }
+        bool isBranch() const override { return true; }
 
         /**
          * Inserts a new branch node under the submenu. The new node
@@ -82,7 +82,7 @@ namespace Kwave
                                              const QString &command,
                                              const QKeySequence &shortcut,
                                              const QString &uid)
-                                             Q_DECL_OVERRIDE;
+                                             override;
 
         /**
          * Inserts a new leaf node under the submenu. The new node
@@ -97,11 +97,11 @@ namespace Kwave
         virtual Kwave::MenuNode *insertLeaf(const QString &name,
                                             const QString &command,
                                             const QKeySequence &shortcut,
-                                            const QString &uid) Q_DECL_OVERRIDE;
+                                            const QString &uid) override;
 
         /** Returns the corresponding menu action */
-        virtual QAction *action() Q_DECL_OVERRIDE {
-            return (m_menu) ? m_menu->menuAction() : Q_NULLPTR;
+        QAction *action() override {
+            return (m_menu) ? m_menu->menuAction() : nullptr;
         }
 
         /**
@@ -109,40 +109,40 @@ namespace Kwave
          * was not found or is already removed this does nothing.
          * @param child pointer to the child node
          */
-        virtual void removeChild(Kwave::MenuNode *child) Q_DECL_OVERRIDE;
+        void removeChild(Kwave::MenuNode *child) override;
 
         /**
          * Handles/interpretes special menu commands.
          * @param command name of a menu node or command
          * @return true if the name was recognized as a command and handled
          */
-        virtual bool specialCommand(const QString &command) Q_DECL_OVERRIDE;
+        bool specialCommand(const QString &command) override;
 
         /**
          * Shows/hides the current sub menu.
          * @param visible true to show the sub menu, false to hide
          */
-        virtual void setVisible(bool visible) Q_DECL_OVERRIDE;
+        void setVisible(bool visible) override;
 
         /**
          * Returns true if the node is enabled.
          */
-        virtual bool isEnabled() Q_DECL_OVERRIDE;
+        bool isEnabled() override;
 
         /**
          * Enables/disables the current menu node.
          * @param enable true to enable the item, false to disable
          */
-        virtual void setEnabled(bool enable) Q_DECL_OVERRIDE;
+        void setEnabled(bool enable) override;
 
         /** Returns the menu nodes' icon. */
-        virtual const QIcon icon() Q_DECL_OVERRIDE;
+        const QIcon icon() override;
 
         /**
          * Sets a new icon of a menu node.
          * @param icon QPixmap with the icon
          */
-        virtual void setIcon(const QIcon &icon) Q_DECL_OVERRIDE;
+        void setIcon(const QIcon &icon) override;
 
     protected:
         friend class MenuRoot;
