@@ -19,6 +19,7 @@
 #define SIGNAL_MANAGER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QList>
@@ -37,8 +38,6 @@
 #include "libkwave/Signal.h"
 #include "libkwave/undo/UndoManager.h"
 
-class QBitmap;
-class QFile;
 class QUrl;
 
 #define NEW_FILENAME i18n("New File")
@@ -52,14 +51,13 @@ namespace Kwave
     class UndoTransactionGuard;
     class MultiTrackWriter;
     class SampleReader;
-    class SignalWidget;
     class Track;
     class Writer;
 
     /**
      * The SignalManager class manages multi channel signals.
      */
-    class Q_DECL_EXPORT SignalManager: public QObject
+    class LIBKWAVE_EXPORT SignalManager: public QObject
     {
         Q_OBJECT
 
@@ -68,7 +66,7 @@ namespace Kwave
         explicit SignalManager(QWidget *parent);
 
         /** Default destructor */
-        virtual ~SignalManager();
+        virtual ~SignalManager() override;
 
         /**
          * Closes the current signal and loads a new file.
