@@ -45,16 +45,16 @@ namespace Kwave
     Q_OBJECT
 
     public:
-        explicit AboutContainer(QWidget *parent = Q_NULLPTR);
+        explicit AboutContainer(QWidget *parent = nullptr);
 
-        virtual ~AboutContainer() Q_DECL_OVERRIDE;
+        ~AboutContainer() override;
 
         void addPerson(const QString &name, const QString &email,
                        const QString &url,  const QString &task);
 
-        virtual QSize sizeHint() const Q_DECL_OVERRIDE;
+        QSize sizeHint() const override;
 
-        virtual QSize minimumSizeHint() const Q_DECL_OVERRIDE;
+        QSize minimumSizeHint() const override;
 
         void addWidget(QWidget *widget);
 
@@ -79,9 +79,9 @@ namespace Kwave
                          const QString &url,
                          const QString &work);
 
-        virtual ~AboutContributor() Q_DECL_OVERRIDE;
+        ~AboutContributor() override;
 
-        QSize sizeHint() const Q_DECL_OVERRIDE;
+        QSize sizeHint() const override;
 
     protected:
         virtual void fontChange( const QFont &oldFont );
