@@ -23,8 +23,6 @@
 #include "libkwave/CodecPlugin.h"
 #include "libkwave/Compression.h"
 
-class QStringList;
-
 namespace Kwave
 {
 
@@ -41,13 +39,13 @@ namespace Kwave
         FlacCodecPlugin(QObject *parent, const QVariantList &args);
 
         /** Destructor */
-        virtual ~FlacCodecPlugin() Q_DECL_OVERRIDE;
+        ~FlacCodecPlugin() override;
 
         /** Creates a new decoder */
-        virtual QList<Kwave::Decoder *> createDecoder() Q_DECL_OVERRIDE;
+        QList<Kwave::Decoder *> createDecoder() override;
 
         /** Creates a new encoder */
-        virtual QList<Kwave::Encoder *> createEncoder() Q_DECL_OVERRIDE;
+        QList<Kwave::Encoder *> createEncoder() override;
 
     private:
         /** static codec container */
