@@ -62,7 +62,7 @@ QStringList *Kwave::MP3CodecPlugin::setup(QStringList &previous_params)
     QPointer<MP3EncoderDialog> dialog =
         new(std::nothrow) MP3EncoderDialog(parentWidget());
     Q_ASSERT(dialog);
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
@@ -71,11 +71,11 @@ QStringList *Kwave::MP3CodecPlugin::setup(QStringList &previous_params)
         dialog->save();
     } else {
         // user pressed "Cancel"
-        if (list) delete list;
-        list = Q_NULLPTR;
+        delete list;
+        list = nullptr;
     }
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 
 }
@@ -96,3 +96,5 @@ QList<Kwave::Encoder *> Kwave::MP3CodecPlugin::createEncoder()
 #include "MP3CodecPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_MP3CodecPlugin.cpp"
