@@ -44,10 +44,10 @@ namespace Kwave
         PitchShiftFilter();
 
         /** Destructor */
-        virtual ~PitchShiftFilter() Q_DECL_OVERRIDE;
+        ~PitchShiftFilter() override;
 
         /** does the calculation */
-        virtual void goOn() Q_DECL_OVERRIDE;
+        void goOn() override;
 
     signals:
 
